import React, { useCallback, useState } from 'react';
import withCondition from '../../withCondition';
import useField from '../../useField';
import { select } from '../../../../../fields/validations';
import SelectInput from './Input';
const formatOptions = (options) => options.map((option) => {
    if (typeof option === 'object' && option.value) {
        return option;
    }
    return {
        label: option,
        value: option,
    };
});
const Select = (props) => {
    const { path: pathFromProps, name, required, validate = select, label, options: optionsFromProps, hasMany, admin: { readOnly, style, width, description, condition, } = {}, } = props;
    const path = pathFromProps || name;
    const [options] = useState(formatOptions(optionsFromProps));
    const memoizedValidate = useCallback((value) => {
        const validationResult = validate(value, { required, options });
        return validationResult;
    }, [validate, required, options]);
    const { value, showError, setValue, errorMessage, } = useField({
        path,
        validate: memoizedValidate,
        condition,
    });
    const onChange = useCallback((selectedOption) => {
        if (!readOnly) {
            let newValue;
            if (hasMany) {
                if (Array.isArray(selectedOption)) {
                    newValue = selectedOption.map((option) => option.value);
                }
                else {
                    newValue = [];
                }
            }
            else {
                newValue = selectedOption.value;
            }
            setValue(newValue);
        }
    }, [
        readOnly,
        hasMany,
        setValue,
    ]);
    return (React.createElement(SelectInput, { path: path, onChange: onChange, value: value, name: name, options: options, label: label, showError: showError, errorMessage: errorMessage, description: description, style: style, width: width, hasMany: hasMany }));
};
export default withCondition(Select);
