/// <reference types="pino" />
import { Express, Router } from 'express';
import { TypeWithID, Collection, PaginatedDocs } from './collections/config/types';
import { SanitizedConfig, EmailOptions, InitOptions } from './config/types';
import { RequestHandlers } from './init/bindRequestHandlers';
import { PayloadAuthenticate } from './express/middleware/authenticate';
import { Globals } from './globals/config/types';
import { GraphQLResolvers } from './graphql/bindResolvers';
import { ErrorHandler } from './express/middleware/errorHandler';
import performFieldOperations from './fields/performFieldOperations';
import { encrypt, decrypt } from './auth/crypto';
import { BuildEmailResult, Message } from './email/types';
import { Preferences } from './preferences/types';
import { Options as CreateOptions } from './collections/operations/local/create';
import { Options as FindOptions } from './collections/operations/local/find';
import { Options as FindByIDOptions } from './collections/operations/local/findByID';
import { Options as UpdateOptions } from './collections/operations/local/update';
import { Options as DeleteOptions } from './collections/operations/local/delete';
/**
 * @description Payload
 */
export declare class Payload {
    config: SanitizedConfig;
    collections: Collection[];
    graphQL: {
        resolvers: GraphQLResolvers;
    };
    preferences: Preferences;
    globals: Globals;
    logger: import("pino").Logger;
    express: Express;
    router: Router;
    emailOptions: EmailOptions;
    email: BuildEmailResult;
    sendEmail: (message: Message) => Promise<unknown>;
    license: string;
    secret: string;
    mongoURL: string;
    local: boolean;
    encrypt: typeof encrypt;
    decrypt: typeof decrypt;
    operations: {
        [key: string]: any;
    };
    errorHandler: ErrorHandler;
    authenticate: PayloadAuthenticate;
    performFieldOperations: typeof performFieldOperations;
    requestHandlers: RequestHandlers;
    /**
     * @description Initializes Payload
     * @param options
     */
    init(options: InitOptions): void;
    getAdminURL: () => string;
    getAPIURL: () => string;
    /**
     * @description Performs create operation
     * @param options
     * @returns created document
     */
    create: <T>(options: CreateOptions) => Promise<T>;
    /**
     * @description Find documents with criteria
     * @param options
     * @returns documents satisfying query
     */
    find: <T extends TypeWithID = any>(options: FindOptions) => Promise<PaginatedDocs<T>>;
    findGlobal: <T>(options: any) => Promise<T>;
    updateGlobal: <T>(options: any) => Promise<T>;
    /**
     * @description Find document by ID
     * @param options
     * @returns document with specified ID
     */
    findByID: <T extends TypeWithID = any>(options: FindByIDOptions) => Promise<T>;
    /**
     * @description Update document
     * @param options
     * @returns Updated document
     */
    update: <T extends TypeWithID = any>(options: UpdateOptions) => Promise<T>;
    delete: <T extends TypeWithID = any>(options: DeleteOptions) => Promise<T>;
    login: (options: any) => Promise<any>;
    forgotPassword: (options: any) => Promise<any>;
    resetPassword: (options: any) => Promise<any>;
    unlock: (options: any) => Promise<any>;
    verifyEmail: (options: any) => Promise<any>;
}
declare const payload: Payload;
export default payload;
